import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataAzureadDomainsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Set to `true` to only return domains whose DNS is managed by Microsoft 365.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#admin_managed DataAzureadDomains#admin_managed}
     *
     * @stability stable
     */
    readonly adminManaged?: boolean | cdktf.IResolvable;
    /**
     * Set to `true` if unverified Azure AD domains should be included.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#include_unverified DataAzureadDomains#include_unverified}
     *
     * @stability stable
     */
    readonly includeUnverified?: boolean | cdktf.IResolvable;
    /**
     * Set to `true` to only return the default domain.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#only_default DataAzureadDomains#only_default}
     *
     * @stability stable
     */
    readonly onlyDefault?: boolean | cdktf.IResolvable;
    /**
     * Set to `true` to only return the initial domain, which is your primary Azure Active Directory tenant domain.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#only_initial DataAzureadDomains#only_initial}
     *
     * @stability stable
     */
    readonly onlyInitial?: boolean | cdktf.IResolvable;
    /**
     * Set to `true` to only return verified root domains. Excludes subdomains and unverified domains.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#only_root DataAzureadDomains#only_root}
     *
     * @stability stable
     */
    readonly onlyRoot?: boolean | cdktf.IResolvable;
    /**
     * A list of supported services that must be supported by a domain.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#supports_services DataAzureadDomains#supports_services}
     *
     * @stability stable
     */
    readonly supportsServices?: string[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#timeouts DataAzureadDomains#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DataAzureadDomainsTimeouts;
}
/**
 * @stability stable
 */
export declare class DataAzureadDomainsDomains extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get adminManaged(): any;
    /**
     * @stability stable
     */
    get authenticationType(): string;
    /**
     * @stability stable
     */
    get default(): any;
    /**
     * @stability stable
     */
    get domainName(): string;
    /**
     * @stability stable
     */
    get initial(): any;
    /**
     * @stability stable
     */
    get root(): any;
    /**
     * @stability stable
     */
    get supportedServices(): string[];
    /**
     * @stability stable
     */
    get verified(): any;
}
/**
 * @stability stable
 */
export interface DataAzureadDomainsTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/domains.html#read DataAzureadDomains#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
/**
 * @stability stable
 */
export declare class DataAzureadDomainsTimeoutsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _read?;
    /**
     * @stability stable
     */
    get read(): string | undefined;
    /**
     * @stability stable
     */
    set read(value: string | undefined);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/d/domains.html azuread_domains}.
 *
 * @stability stable
 */
export declare class DataAzureadDomains extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/d/domains.html azuread_domains} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataAzureadDomainsConfig);
    private _adminManaged?;
    /**
     * @stability stable
     */
    get adminManaged(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set adminManaged(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAdminManaged(): void;
    /**
     * @stability stable
     */
    get adminManagedInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    domains(index: string): DataAzureadDomainsDomains;
    /**
     * @stability stable
     */
    get id(): string;
    private _includeUnverified?;
    /**
     * @stability stable
     */
    get includeUnverified(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set includeUnverified(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetIncludeUnverified(): void;
    /**
     * @stability stable
     */
    get includeUnverifiedInput(): boolean | cdktf.IResolvable | undefined;
    private _onlyDefault?;
    /**
     * @stability stable
     */
    get onlyDefault(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set onlyDefault(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetOnlyDefault(): void;
    /**
     * @stability stable
     */
    get onlyDefaultInput(): boolean | cdktf.IResolvable | undefined;
    private _onlyInitial?;
    /**
     * @stability stable
     */
    get onlyInitial(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set onlyInitial(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetOnlyInitial(): void;
    /**
     * @stability stable
     */
    get onlyInitialInput(): boolean | cdktf.IResolvable | undefined;
    private _onlyRoot?;
    /**
     * @stability stable
     */
    get onlyRoot(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set onlyRoot(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetOnlyRoot(): void;
    /**
     * @stability stable
     */
    get onlyRootInput(): boolean | cdktf.IResolvable | undefined;
    private _supportsServices?;
    /**
     * @stability stable
     */
    get supportsServices(): string[] | undefined;
    /**
     * @stability stable
     */
    set supportsServices(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetSupportsServices(): void;
    /**
     * @stability stable
     */
    get supportsServicesInput(): string[] | undefined;
    private _timeouts?;
    private __timeoutsOutput;
    /**
     * @stability stable
     */
    get timeouts(): DataAzureadDomainsTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DataAzureadDomainsTimeouts | undefined): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataAzureadDomainsTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
